Impressum — mosaik 2.3.1 documentation

# Impressum

Anschrift

OFFIS e. V.
Escherweg 2
26121 Oldenburg
Telefon +49 441 9722-0
Fax +49 441 9722-102
E-Mail: institut [ A T ] offis.de
Internet: www.offis.de

Vertretungsberechtigter Vorstand

Prof. Dr.-Ing. Wolfgang H. Nebel (Vorsitzender)
Prof. Dr. techn. Susanne Boll-Westermann
Prof. Dr. Werner Damm
Prof. Dr.-Ing. Andreas Hein
Prof. Dr. Sebastian Lehnhoff

Registergericht

Amtsgericht Oldenburg
Registernummer VR 1956

Umsatzsteuer-Identifikationsnummer (USt-IdNr.)

DE 811582102

Inhaltlich Verantwortlicher gemäß § 55 RStV

Dr. Christoph Mayer (Bereichsleiter)
OFFIS e.V.
Escherweg 2
26121 Oldenburg

Datenschutz

Mehr zum Thema Datenschutz finden Sie hier.